Learn R Programming

octopucs (version 0.1.1)

F1: Labeling of memberships of two groups

Description

Internal function to label the membership of two clusters

Usage

F1(A, B)

Value

Produced a two-column matrix populated with zeros and ones to indicate what IDs (row names) are included in each of two vectors in which some element may be shared

Arguments

A

Memberships in the first cluster

B

Membership in the second cluster

Author

Roger Guevara (roger.guevara@inecol.mx)