Learn R Programming

octopucs (version 0.1.1)

IDscluster2: Memberships of Groups and Subgroups

Description

Identify the memberships at every level of the topology in the bootstrapped clusters.

Usage

IDscluster2(M2=M2)

Value

A list object with the memberships for the groups and subgroups all through the topology of the generalized cluster

Arguments

M2

List object generated by glzcluster or glzcluster2

Author

Roger Guevara (roger.guevara@inecol.mx) & Ian MacGregor-Fors (ian.macgregor@helsinki.fi)

References

Koleff, P., Gaston, K.J., Lennon, J. J. 2003. Measuring beta diversity for presence-absence data. Journal of Animal Ecology 71:367. https://doi.org/10.1046/j.1365-2656.2003.00710.x

Examples

Run this code
data(dune)
M2 <- glzcluster(dune, n=5, prop=0.8, distance="bray", method="average")
GRPs <- IDscluster2(M2[[length(M2)]])
GRPs

Run the code above in your browser using DataLab