glzcs: Support for Groups and Subgroups
in the Generalized Dendrogram
Description
Generates three metrics
of support for the observed clusters
at all hierarchical levels
Usage
glzcs(GRPs=GRPs, M2=M2)
Value
A table with supporting values and size of every group: integrity,
contamination, probability and group size.
Arguments
GRPs
List object generated by the functions IDscluster & IDscluster2
M2
Class list object generated by the functions glzcluster or glzcluster2
Author
Roger Guevara (roger.guevara@inecol.mx) &
Ian MacGregor-Fors (ian.macgregor@helsinki.fi)
References
Koleff, P., Gaston, K.J., Lennon, J. J. 2003. Measuring beta diversity for
presence-absence data. Journal of Animal Ecology 71:367.
https://doi.org/10.1046/j.1365-2656.2003.00710.x