powered by
Internal function to label the membership of two clusters
F1(A, B)
Produced a two-column matrix populated with zeros and ones to indicate what IDs (row names) are included in each of two vectors in which some element may be shared
Memberships in the first cluster
Membership in the second cluster
Roger Guevara (roger.guevara@inecol.mx)